## About The Project

This repository contains the codebase for Monkey Music image processing library.


### Built With <a name = "built-with"></a>
The list of all the major technologies used in the project.
- [Rust](https://doc.rust-lang.org/)


## Getting Started
1. Please setup the rust toolchain using instructions at https://doc.rust-lang.org/book/ch01-01-installation.html
2. Clone this repo.
3. Build codebase with `cargo build --release`


<!-- CONTRIBUTING -->
## Contributing

Follow the steps below to contribute to the project. Please ensure code is properly tested and the total lines of code
is not more than 20 lines for each pull request

1. Fork the Project
2. Create your Feature Branch 
3. Commit your Changes.
4. Push to the Branch
5. Open a Pull Request
